@@ -14,8 +14,10 @@
 
 import socket
 import struct
+from logging import Logger
 
 import time
+from typing import Any, Optional
 
 
 class ErrorReporter(object):
@@ -26,12 +28,14 @@ class ErrorReporter(object):
     N.B. metrics will be deprecated in the future
     """
 
-    def __init__(self, metrics, logger=None, log_interval_minutes=15):
+    def __init__(
+        self, metrics: Any, logger: Optional[Logger] = None, log_interval_minutes: int = 15
+    ):
         self.logger = logger
         self.log_interval_minutes = log_interval_minutes
         self._last_error_reported_at = time.time()
 
-    def error(self, *args):
+    def error(self, *args: Any) -> None:
         if self.logger is None:
             return
 
@@ -46,7 +50,7 @@ class ErrorReporter(object):
         self._last_error_reported_at = current_time
 
 
-def get_boolean(string, default):
+def get_boolean(string: str, default: bool) -> bool:
     string = str(string).lower()
     if string in ['false', '0', 'none']:
         return False
@@ -56,8 +60,10 @@ def get_boolean(string, default):
         return default
 
 
-def local_ip():
+def local_ip() -> Optional[str]:
     """Get the local network IP of this machine"""
+    ip: Optional[str]
+
     try:
         ip = socket.gethostbyname(socket.gethostname())
     except IOError:
@@ -69,7 +75,7 @@ def local_ip():
     return ip
 
 
-def get_local_ip_by_socket():
+def get_local_ip_by_socket() -> Optional[str]:
     # Explanation : https://stackoverflow.com/questions/166506
     s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
     try:
@@ -83,7 +89,7 @@ def get_local_ip_by_socket():
     return ip
 
 
-def get_local_ip_by_interfaces():
+def get_local_ip_by_interfaces() -> Optional[str]:
     ip = None
     # Check eth0, eth1, eth2, en0, ...
     interfaces = [
@@ -99,7 +105,7 @@ def get_local_ip_by_interfaces():
     return ip
 
 
-def interface_ip(interface):
+def interface_ip(interface: bytes) -> Optional[str]:
     try:
         import fcntl
         """Determine the IP assigned to us by the given network interface."""
